package sav.example.javaz;
import sav.z.*;
import java.io.*;
/**
 * This is example of the Base methods, which may accelerate
 * performance against the execution of Zigzag scripts.
 * It is possible a direct access to the attribute values
 * of known objects.
 */
public class DBGroupingDemo {
  public static void main(String arg[]) throws IOException {
    String script =
      "$readTable() <" +
      "employee; name;           department; salary \n" +
      "101;      'Adams Smith';  1;          50000 \n" +
      "102;      'Clark White';  1;          30000 \n" +
      "103;      'Jones Hunter'; 2;          60000 \n" +
      "104;      'Blake Dull';   3;          65000 \n" +
      "105;      'Sylvia Smith'; 1;          25000 \n" +
      "108;      'Albert Green'; 3;          40000 \n" +
      "109;      'Clark Ringer'; 2;          50000 \n" +
      ">;"
    ;
    Session ss = new Session();
    ss.modifyBase("CompanyX");
    ss.z(script);

    /**
     * Following is an iteration over the set of ascendant
     * values of the department class. This example
     * groups employees, their count and salary sum
     * by the departments.
     */
    ss.exploreBase("CompanyX");
    Base bx = ss.base();
    int depCount = bx.size("department");
    int peopleCount[] = new int[depCount + 1];
    float salarySum[] = new float[depCount + 1];
    for (String dep = bx.first("department"); dep != null; dep = bx.next("department", dep)) {
      int depNumber = Integer.parseInt(dep);
      peopleCount[depNumber] = bx.attrSize("department:" + dep, "employee");
      String emp = bx.attrFirst("department:" + dep, "employee");
      while (emp != null) {
        String salary = bx.attrValue("employee:" + emp, "salary");
        if (salarySum[depNumber] == 0.0)
          salarySum[depNumber] = Float.parseFloat(salary);
        else
          salarySum[depNumber] += Float.parseFloat(salary);
        emp = bx.attrNext("department:" + dep, "employee", emp);
      }
    }
    System.out.println("department; people_count; salary_sum");
    for (int i = 1; i <= depCount; ++i) {
      if (peopleCount[i] == 0)
        continue;
      System.out.println(i + "; " +  peopleCount[i] + "; " + salarySum[i]);
    }
    bx.close();

  }
}
